import React, { useEffect, useState } from 'react';
import { View, Text, StyleSheet, TouchableOpacity, ScrollView } from 'react-native';
import { Icon } from "@rneui/themed";
import { api } from '../services/api';
import { AxiosError } from 'axios';
import { callToast } from '../utils/toast';

interface ColapseProps {
  description: string;
  id: Number
}
type ClinicItem = {
  id: Number,
  name: string,
  district: string,
  cep: string,
  city: string,
  street: string,
  isHomeOffice: boolean,
  workPhone: string,
  occupationArea: string,
  state: string,
  adressNumber: number,
  complement: string
}


export function Collapse({ description, id }: ColapseProps) {
  const [clinics, setClinics] = useState<ClinicItem[]>([]);
  const [descriptionVisible, setdescriptionVisible] = useState(false);
  const [clinicsVisible, setclinicsVisible] = useState(false);

  const touchDescription = (): void => {
    setdescriptionVisible(!descriptionVisible)
    setclinicsVisible(false);
  };

  const touchClinic = (): void => {
    setclinicsVisible(!clinicsVisible)
    setdescriptionVisible(false);
  };

  useEffect(() => {
    api.get(`/clinics/${id}`).then((response) => {
      setClinics(response.data);
    }).catch((error: AxiosError) => callToast(error.code as string));
  }, [])

  return (
    <>
      <TouchableOpacity style={styles.headerDescription} onPress={() => touchDescription()}>
        <Text style={styles.headerText}>Descrição</Text>
        <Icon style={styles.icon} name={descriptionVisible ? 'keyboard-arrow-up' : 'keyboard-arrow-down'} size={30} />
      </TouchableOpacity>

      {descriptionVisible ? (
        <View style={styles.descriptionContent}>
          <Text>{description}</Text>
        </View>
      ) : null
      }

      <TouchableOpacity style={styles.headerClinics} onPress={() => touchClinic()}>
        <Text style={styles.headerText}>Clínicas</Text>
        <Icon style={styles.icon} name={clinicsVisible ? 'keyboard-arrow-up' : 'keyboard-arrow-down'} size={30} />
      </TouchableOpacity>

      {clinicsVisible ? (
        clinics.map(item => {
          return (
            item.isHomeOffice === false ? (
              <View style={styles.clinicsContent}>
                <React.Fragment key={item.name}>
                  <Text>{item.name}</Text>
                  <View style={styles.adrees}>
                    <Text style={styles.adrees}>{item.street} {item.adressNumber}, {item.complement}, {item.district} - {item.city} - {item.state}</Text>
                  </View>
                  <Text>Especialização: {item.occupationArea}</Text>

                </React.Fragment>
              </View>
            ) : (<View style={styles.clinicsContent}>
              <React.Fragment key={item.name}>
                <Text>{"Homeoffice"}</Text>
                <Text>Especialização: {item.occupationArea}</Text>
                <Text>Contato: {item.workPhone}</Text>
              </React.Fragment>
            </View>)
          )
        })
      ) : null
      }
    </>
  );
}

const styles = StyleSheet.create({
  descriptionContent: {
    alignItems: "flex-start",
    justifyContent: 'center',
    backgroundColor: '#F8F6FD',
    width: '85%',
    paddingVertical: 33,
    paddingHorizontal: 18,
    borderBottomWidth: 1,
    borderBottomColor: '#ECECED',
  },
  clinicsContent: {
    alignItems: "flex-start",
    justifyContent: 'center',
    backgroundColor: '#F8F6FD',
    width: '85%',
    paddingVertical: 33,
    paddingHorizontal: 18,
    borderBottomWidth: 1,
    borderBottomColor: '#ECECED',
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
  },
  adrees: {
    flexDirection: 'row',
  },
  headerDescription: {
    width: '85%',
    height: 60,
    backgroundColor: '#F8F6FD',
    lineHeight: 22,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    borderBottomWidth: 2,
    borderBottomColor: '#ECECED',
    borderTopStartRadius: 10,
    borderTopRightRadius: 10,
  },
  headerClinics: {
    width: '85%',
    height: 60,
    backgroundColor: '#F8F6FD',
    lineHeight: 22,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    borderBottomWidth: 2,
    borderBottomColor: '#ECECED',
    borderBottomLeftRadius: 10,
    borderBottomRightRadius: 10,
  },
  headerText: {
    justifyContent: 'center',
    fontWeight: '800',
    alignItems: 'flex-start',
    paddingLeft: 16,
    paddingVertical: 13,
    letterSpacing: 0.75
  },
  icon: {
    justifyContent: 'center',
    paddingVertical: 9,
  },
  contentText: {
    height: 400,
    fontSize: 14,
    lineHeight: 22,
  },

});