import React, { useRef } from "react";
import { StyleSheet, Text, TouchableOpacity, View } from "react-native";
import { Card, Icon } from "@rneui/themed";
import { colorPalette } from "./Theme";

interface Props {
  title: string;
  description: string;
  imageUri?: string;
  icon: { type: string; name: string };
  onPress?: any;
}

export function HomeCard({
  title,
  description,
  imageUri,
  icon,
  onPress,
  ...props
}: Props) {
  const menuButtonRef = useRef();

  const handleOnPress = (event) => {
    if (onPress) {
      onPress();
    }
  };

  return (
    <>
      <TouchableOpacity ref={menuButtonRef} onPress={handleOnPress}>
        <Card>
          <Card.Image
            source={{
              uri: imageUri,
            }}
            style={styles.card__image}
            resizeMode="cover"
          />
          <View style={styles.card_bar}>
            <View style={styles.card_bar__icon}>
              <Icon type={icon.type} name={icon.name} size={28} />
            </View>
            <View style={{ width: "75%" }}>
              <Text
                style={{
                  fontWeight: "700",
                  fontSize: 24,
                  lineHeight: 36,
                  color: colorPalette.neutral[900],
                }}
              >
                {title}
              </Text>
              <Text
                style={{
                  fontWeight: "400",
                  fontSize: 12,
                  lineHeight: 20,
                  letterSpacing: 0.75,
                  color: colorPalette.neutral[900],
                }}
              >
                {description}
              </Text>
            </View>
          </View>
        </Card>
      </TouchableOpacity>
    </>
  );
}

const styles = StyleSheet.create({
  card__image: {
    width: "100%",
    borderTopLeftRadius: 16,
    borderTopRightRadius: 16,
    display: "flex",
  },
  card_bar: {
    display: "flex",
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    overflow: "hidden",
    paddingHorizontal: 10,
  },
  card_bar__icon: {
    borderRadius: 10,
    backgroundColor: colorPalette.neutral[100],
    height: 60,
    width: "25%",
    display: "flex",
    justifyContent: "center",
    marginRight: 10,
  },
});

export default HomeCard;
