import React from "react";
import { StyleSheet, TextInput, TextInputProps, Text } from "react-native";
import { colorPalette } from "./Theme";

interface InputDefaultProps extends TextInputProps {
  error?: string;
}

export function InputDefault({ error, ...rest }: InputDefaultProps) {
  return (
    <>
      <TextInput
        style={styles.input}
        underlineColorAndroid="transparent"
        placeholderTextColor={"#8b9cb5"}
        maxLength={35}
        {...rest}
      />
      {error && <Text style={styles.error}>{error}</Text>}
    </>
  );
}

const styles = StyleSheet.create({
  input: {
    backgroundColor: colorPalette.neutral[100],
    paddingLeft: 20,
    margin: 10,
    borderRadius: 16,
    width: '85%',
    height: 64,
    fontSize: 20,
  },
  error: {
    color: '#ff4040',
    alignSelf: 'flex-start',
    paddingLeft: 40,
    marginTop: -10,
  }
})

