import React from "react";
import { StyleSheet, Text } from "react-native";
import { TextInputMask, TextInputMaskProps } from "react-native-masked-text";
import { colorPalette } from "./Theme";

interface InputMaskedProps extends TextInputMaskProps {
  error?: string;
}

export function InputMasked({ error, ...rest }: InputMaskedProps) {
  return (
    <>
      <TextInputMask
        style={styles.input}
        underlineColorAndroid="transparent"
        placeholderTextColor={"#8b9cb5"}
        {...rest}
      />
      {error && <Text style={styles.error}>{error}</Text>}
    </>
  );
}

const styles = StyleSheet.create({
  input: {
    backgroundColor: colorPalette.neutral[100],
    paddingLeft: 20,
    margin: 10,
    borderRadius: 16,
    width: '85%',
    height: 64,
    fontSize: 20,
    fontWeight: "400",
  },
  error: {
    color: '#ff4040',
    alignSelf: 'flex-start',
    paddingLeft: 40,
    marginTop: -10,
  }
})

