import React, { useState } from 'react';
import { useNavigation } from '@react-navigation/native';
import { isEmailValid, isPasswordsEqualsValid, isPasswordValid } from '../../utils/validations';
import { InputDefault } from '../InputDefault';
import { View, StyleSheet } from 'react-native';
import { RoundButton } from '../RoundButton';
import { PaginationItem } from '../PaginationItem';
import { User, useUser } from '../../services/hooks/useUser';

interface PatientStepFourProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function PatientStepFour({ setStep, setUserData, userData }: PatientStepFourProps) {
  const navigation = useNavigation();
  const [password, setPassword] = useState('');
  const [passwordConfirmation, setPasswordConfirmation] = useState('');
  const { setUser, createUser, login } = useUser();
  const [emailError, setEmailError] = useState('');
  const [passwordError, setPasswordError] = useState('');
  const [passwordConfirmationError, setPasswordConfirmationError] = useState('');

  async function inputValidation() {
    const emailValidation = isEmailValid(userData.email)
    emailValidation !== 'valid' ?
      setEmailError(emailValidation) : setEmailError('')

    const passwordValidation = isPasswordValid(password)
    passwordValidation !== 'valid' ?
      setPasswordError(passwordValidation) : setPasswordError('')

    const passwordsEqualsValidation = isPasswordsEqualsValid(password, passwordConfirmation)
    passwordsEqualsValidation !== 'valid' ?
      setPasswordConfirmationError(passwordsEqualsValidation) : setPasswordConfirmationError('')

    if (passwordsEqualsValidation === 'valid' && passwordValidation === 'valid' && emailValidation === 'valid') {
      const newPatient: User = {
        ...userData,
        password,
        userType: "PATIENT"
      };
      setUserData(newPatient);
      setUser(newPatient);
      if (newPatient) {
        const responseCode = await createUser(newPatient);
        if (responseCode === 200) {
          const responseCodeLogin = await login({email: newPatient.email, password: newPatient.password});
          if(responseCodeLogin === 200){
            navigation.navigate('TabScreens', { screen: 'PatientHome', initial: false });
          }
        }
      }
    }
  }

  return (
    <>
      <InputDefault placeholder='E-mail'
        keyboardType="email-address"
        value={userData.email}
        onChangeText={text => setUserData({ ...userData, email: text })}
        error={emailError}
      />
      <InputDefault placeholder='Senha'
        secureTextEntry
        value={password}
        onChangeText={text => setPassword(text)}
        error={passwordError}
      />
      <InputDefault placeholder='Confirmar Senha'
        value={passwordConfirmation}
        secureTextEntry
        onChangeText={text => setPasswordConfirmation(text)}
        error={passwordConfirmationError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(3)} />
        <PaginationItem current={4} />
        <RoundButton variant="check" onPress={inputValidation} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
});