import React, { useState } from 'react';
import { View, StyleSheet } from 'react-native';
import { User } from '../../services/hooks/useUser';
import { isNameValid, isBirthdayValid, isCpfValid } from '../../utils/validations';
import { InputDefault } from '../InputDefault';
import { InputMasked } from '../InputMasked';
import { PaginationItem } from '../PaginationItem';
import { RoundButton } from '../RoundButton';

interface PatientStepThreeProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function PatientStepThree({ setStep, setUserData, userData }: PatientStepThreeProps) {
  const [nameError, setNameError] = useState('');
  const [birthdayError, setBirthdayError] = useState('');
  const [cpfError, setCpfError] = useState('');

  function inputValidation() {
    const nameValidation = isNameValid(userData.name)
    nameValidation !== 'valid' ?
      setNameError(nameValidation) : setNameError('')

    const birthdayValidation = isBirthdayValid(userData.birthday)
    birthdayValidation !== 'valid' ?
      setBirthdayError(birthdayValidation) : setBirthdayError('')

    const cpfValidation = isCpfValid(userData.cpf)
    cpfValidation !== 'valid' ?
      setCpfError(cpfValidation) : setCpfError('')

    if (nameValidation === 'valid' && birthdayValidation === 'valid' && cpfValidation === 'valid') {
      setStep(4)
    }
  }

  return (
    <>
      <InputDefault
        placeholder='Nome completo do paciente'
        value={userData.name}
        onChangeText={text => setUserData({ ...userData, name: text })}
        error={nameError}
      />
      <InputMasked
        placeholder='Data de nascimento'
        keyboardType="numeric"
        value={userData.birthday}
        type={'datetime'}
        options={{
          format: 'DD/MM/YYYY'
        }}
        onChangeText={text => setUserData({ ...userData, birthday: text })}
        error={birthdayError}
      />
      <InputMasked
        placeholder='CPF'
        value={userData.cpf}
        keyboardType="numeric"
        type={"cpf"}
        onChangeText={text => setUserData({ ...userData, cpf: text })}
        error={cpfError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(2)} />
        <PaginationItem current={3} />
        <RoundButton variant="right" onPress={inputValidation} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
});