import React, { useState } from 'react';
import { isNameValid, isPhoneValid } from '../../utils/validations';
import { InputDefault } from '../InputDefault';
import { InputMasked } from '../InputMasked';
import { StyleSheet, View } from 'react-native';
import { RoundButton } from '../RoundButton';
import { PaginationItem } from '../PaginationItem';
import { User } from '../../services/hooks/useUser';

interface PatientStepTwoProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function PatientStepTwo({ setStep, setUserData, userData }: PatientStepTwoProps) {
  const [responsibleNameError, setResponsibleNameError] = useState('');
  const [phoneError, setPhoneError] = useState('');

  function inputValidation() {
    const nameValidation = isNameValid(userData.responsibleName)
    nameValidation !== 'valid' ?
      setResponsibleNameError(nameValidation) : setResponsibleNameError('')

    const phoneValidation = isPhoneValid(userData.phone)
    phoneValidation !== 'valid' ?
      setPhoneError(phoneValidation) : setPhoneError('')

    if (nameValidation === 'valid' && phoneValidation === 'valid') {
      setStep(3)
    }
  }

  return (
    <>
      <InputDefault
        placeholder='Nome completo do responsável'
        value={userData.responsibleName}
        onChangeText={text => setUserData({ ...userData, responsibleName: text })}
        error={responsibleNameError}
      />
      <InputMasked placeholder='Celular'
        keyboardType="numeric"
        type={"cel-phone"}
        value={userData.phone}
        options={{
          maskType: 'BRL',
          withDDD: true,
          dddMask: '(99) '
        }}
        onChangeText={text => setUserData({ ...userData, phone: text })}
        error={phoneError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(1)} />
        <PaginationItem current={2} />
        <RoundButton variant="right" onPress={inputValidation} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
});