import React, { useState } from 'react';
import { View, StyleSheet } from 'react-native';
import { User } from '../../services/hooks/useUser';
import { callToast } from '../../utils/toast';
import { PaginationItem } from '../PaginationItem';
import { RoundButton } from '../RoundButton';
import VerticalCheckboxGroupContainer from '../VerticalCheckboxGroupContainer';

interface PatientStepOneProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
}

export function SignUpUserOption({ setStep, setUserData }: PatientStepOneProps) {
  const [selected, setSelected] = useState(0);

  function setSelectedStep() {
    if (selected === 1) {
      setUserData({});
      setStep(2);
    } else if (selected === 2) {
      setUserData({});
      setStep(5);
    } else {
      callToast('Opção inválida');
    }
  }

  return (
    <>
      <VerticalCheckboxGroupContainer setSelected={setSelected} />
      <View style={styles.pagination}>
        <View style={styles.fakeView}></View>
        <PaginationItem current={1} />
        <RoundButton variant="right" onPress={() => setSelectedStep()} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
  fakeView: {
    width: 54,
    height: 54,
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 100,
    backgroundColor: 'white',
    marginHorizontal: 12
  }
});