import React, { useState } from "react";
import { useNavigation } from "@react-navigation/native";
import {
  isPasswordsEqualsValid,
  isPasswordValid,
} from "../../utils/validations";
import { InputDefault } from "../InputDefault";
import { View, StyleSheet } from "react-native";
import { RoundButton } from "../RoundButton";
import { PaginationItem } from "../PaginationItem";
import { User, useUser } from "../../services/hooks/useUser";

interface SpecialistStepFourProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function SpecialistStepFour({ setStep, setUserData, userData }: SpecialistStepFourProps) {
  const navigation = useNavigation();
  const [password, setPassword] = useState("");
  const [passwordConfirmation, setPasswordConfirmation] = useState("");
  const { setUser, createUser, login } = useUser();
  const [passwordError, setPasswordError] = useState("");
  const [passwordConfirmationError, setPasswordConfirmationError] = useState("");

  async function inputValidation() {
    const passwordValidation = isPasswordValid(password);
    passwordValidation !== "valid"
      ? setPasswordError(passwordValidation)
      : setPasswordError("");

    const passwordsEqualsValidation = isPasswordsEqualsValid(
      password,
      passwordConfirmation
    );
    passwordsEqualsValidation !== "valid"
      ? setPasswordConfirmationError(passwordsEqualsValidation)
      : setPasswordConfirmationError("");

    if (
      passwordsEqualsValidation === "valid" &&
      passwordValidation === "valid"
    ) {
      const newSpecialist: User = {
        ...userData,
        password,
        userType: "SPECIALIST",
      };
      setUserData(newSpecialist);
      setUser(newSpecialist);
      if (newSpecialist) {
        const responseCode = await createUser(newSpecialist);
        if (responseCode === 200) {
          const responseCodeLogin = await login({email: newSpecialist.email, password: newSpecialist.password});
          if(responseCodeLogin === 200){
            navigation.navigate('ClinicRegistration')
          }
        }
      }
    }
  }

  return (
    <>
      <InputDefault
        placeholder="Senha"
        secureTextEntry
        value={password}
        onChangeText={(text) => setPassword(text)}
        error={passwordError}
      />
      <InputDefault
        placeholder="Confirmar Senha"
        value={passwordConfirmation}
        secureTextEntry
        onChangeText={(text) => setPasswordConfirmation(text)}
        error={passwordConfirmationError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(6)} />
        <PaginationItem current={7} />
        <RoundButton variant="check" onPress={inputValidation} />
      </View>
    </>
  );
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "center",
    marginTop: 50,
  },
});
