import React, { useState } from 'react';
import { View, StyleSheet } from 'react-native';
import { User } from '../../services/hooks/useUser';
import { isEmailValid, isCpfValid, isCrmValid } from '../../utils/validations';
import { InputDefault } from '../InputDefault';
import { InputMasked } from '../InputMasked';
import { PaginationItem } from '../PaginationItem';
import { RoundButton } from '../RoundButton';

interface SpecialistStepThreeProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function SpecialistStepThree({ setStep, setUserData, userData }: SpecialistStepThreeProps) {
  const [emailError, setEmailError] = useState('');
  const [cpfError, setCpfError] = useState('');
  const [crmError, setCrmError] = useState('');

  function inputValidation() {
    const emailValidation = isEmailValid(userData.email)
    emailValidation !== 'valid' ?
      setEmailError(emailValidation) : setEmailError('')

    const cpfValidation = isCpfValid(userData.cpf)
    cpfValidation !== 'valid' ?
      setCpfError(cpfValidation) : setCpfError('')

    const crmValidation = isCrmValid(userData.crm)
    crmValidation !== 'valid' ?
      setCrmError(crmValidation) : setCrmError('')

    if (emailValidation === 'valid' && cpfValidation === 'valid' && crmValidation === 'valid') {
      setStep(7)
    }
  }

  return (
    <>
      <InputDefault
        placeholder='E-mail'
        keyboardType="email-address"
        value={userData.email}
        onChangeText={text => setUserData({ ...userData, email: text })}
        error={emailError}
      />
      <InputMasked
        placeholder='CPF'
        value={userData.cpf}
        keyboardType="numeric"
        type={"cpf"}
        onChangeText={text => setUserData({ ...userData, cpf: text })}
        error={cpfError}
      />
      <InputDefault
        placeholder='CRM/CRP'
        keyboardType="numeric"
        value={userData.crm}
        onChangeText={text => setUserData({ ...userData, crm: text })}
        error={crmError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(5)} />
        <PaginationItem current={6} />
        <RoundButton variant="right" onPress={inputValidation} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
});