import React, { useState } from 'react';
import { View, StyleSheet } from 'react-native';
import { User } from '../../services/hooks/useUser';
import { isBirthdayValid, isNameValid, isPhoneValid } from '../../utils/validations';
import { InputDefault } from '../InputDefault';
import { InputMasked } from '../InputMasked';
import { PaginationItem } from '../PaginationItem';
import { RoundButton } from '../RoundButton';

interface SpecialistStepTwoProps {
  setStep: React.Dispatch<React.SetStateAction<number>>;
  setUserData: React.Dispatch<React.SetStateAction<User>>;
  userData: User;
}

export function SpecialistStepTwo({ setStep, setUserData, userData }: SpecialistStepTwoProps) {
  const [birthdayError, setBirthdayError] = useState('');
  const [nameError, setNameError] = useState('');
  const [phoneError, setPhoneError] = useState('');

  function inputValidation() {
    const nameValidation = isNameValid(userData.name)
    nameValidation !== 'valid' ?
      setNameError(nameValidation) : setNameError('')

    const birthdayValidation = isBirthdayValid(userData.birthday)
    birthdayValidation !== 'valid' ?
      setBirthdayError(birthdayValidation) : setBirthdayError('')

    const phoneValidation = isPhoneValid(userData.phone)
    phoneValidation !== 'valid' ?
      setPhoneError(phoneValidation) : setPhoneError('')

    if (nameValidation === 'valid' && birthdayValidation === 'valid' && phoneValidation === 'valid') {
      setStep(6)
    }
  }

  return (
    <>
      <InputDefault
        placeholder='Nome completo'
        value={userData.name}
        onChangeText={text => setUserData({ ...userData, name: text })}
        error={nameError}
      />
      <InputMasked
        placeholder='Data de nascimento'
        keyboardType="numeric"
        value={userData.birthday}
        type={'datetime'}
        options={{
          format: 'DD/MM/YYYY'
        }}
        onChangeText={text => setUserData({ ...userData, birthday: text })}
        error={birthdayError}
      />
      <InputMasked placeholder='Celular'
        keyboardType="numeric"
        type={"cel-phone"}
        value={userData.phone}
        options={{
          maskType: 'BRL',
          withDDD: true,
          dddMask: '(99) '
        }}
        onChangeText={text => setUserData({ ...userData, phone: text })}
        error={phoneError}
      />
      <View style={styles.pagination}>
        <RoundButton variant="left" onPress={() => setStep(1)} />
        <PaginationItem current={5} />
        <RoundButton variant="right" onPress={inputValidation} />
      </View>
    </>
  )
}

const styles = StyleSheet.create({
  pagination: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 50
  },
});