import React from 'react';
import { View, StyleSheet, Text, TouchableOpacity } from 'react-native';

interface SpecialistCardProps {
  name: string;
  occupationArea: string;
  description: string;
  onPress(): void;
}

export function SpecialistCard({ name, description, occupationArea, onPress }: SpecialistCardProps) {

  return (
    <TouchableOpacity style={styles.container} onPress={onPress} >
      <View style={styles.item}>
      </View>
      <View style={styles.info}>
        <Text style={styles.name}>{name}</Text>
        <Text style={styles.ocupation}>{occupationArea}</Text>
        <Text style={styles.description}>{description}</Text>
      </View>
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    backgroundColor: '#6D4FD30D',
    alignItems: 'center',
    marginHorizontal: '5%',
    margin: 10,
    padding: 10,
    borderRadius: 16,
  },
  item: {
    backgroundColor: '#5D7684',
    borderRadius: 16,
    height: 52,
    width: 52,
    marginRight: 15,
  },
  info: {
    flex: 1,
    padding: 5,
  },
  name: {
    lineHeight: 22,
    fontSize: 16,
    fontWeight: '700',
    letterSpacing: 0.41,
  },
  ocupation: {
    lineHeight: 22,
    fontSize: 13,
    fontWeight: '300',
  },
  description: {
    lineHeight: 18,
    fontSize: 14,
    fontWeight: '400',
    color: '#000000',
  },


});