import React, { useEffect, useState } from "react";
import { NavigationContainer } from "@react-navigation/native"
import { createNativeStackNavigator } from "@react-navigation/native-stack";
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import { Login } from "../screens/Login";
import { PatientDiaryDay } from "../screens/PatientDiaryDay";
import { SignUp } from "../screens/SignUp";
import { Home } from "../screens/Home";
import { Profile } from "../screens/Profile";
import { FontAwesome5, Entypo, FontAwesome } from '@expo/vector-icons';
import { NavigationBarItem } from "../components/NavigationBarItem";
import { ChecklistResult } from "../screens/ChecklistResult";
import { Checklist } from "../screens/Checklist";
import { ClinicRegistration } from "../screens/ClinicRegistration";
import { ChecklistInfo } from "../screens/ChecklistInfo";
import { TalkToSpecialist } from "../screens/TalkToSpecialist";
import { SpecialistDetails } from "../screens/SpecialistDetails";
import { EditUserInfo } from "../screens/EditUserInfo";
import { EditDescription } from "../screens/EditDescription";
import { SpecialistContact } from "../screens/SpecialistContact";
import { PatientDiaryCalendar } from "../screens/PatientDiaryCalendar";
import { useUser } from "../services/hooks/useUser";
import { PatientDiaryDaySpecialist } from "../screens/PatientDiaryDaySpecialist";
import { PatientDiaryEntries } from "../screens/PatientDiaryEntries";
import { InfoPage } from "../screens/InfoPage";
import { Chat } from "../screens/Chat";
import { ChatList } from "../screens/ChatList";

const Stack = createNativeStackNavigator();
const Tab = createBottomTabNavigator();

export function Routes() {
  const { user } = useUser();
  const [type, setType] = useState('PATIENT');

  useEffect(() => {
    setType(user.userType);
  }, [user])

  function TabScreens() {
    return (
      <Tab.Navigator
        initialRouteName="Início"
        screenOptions={{
          tabBarInactiveTintColor: '#74B8CC',
          tabBarActiveTintColor: '#007BAE',
          tabBarActiveBackgroundColor: '#F5F6F7',
          tabBarInactiveBackgroundColor: '#F5F6F7',
          tabBarStyle: { height: 60, paddingBottom: 10, backgroundColor: '#F5F6F7' },
          headerShadowVisible: false
        }}
      >
        <Tab.Screen name="Diário"
          component={type === 'PATIENT' ? PatientDiaryCalendar : Home}
          options={{
            headerTitleAlign: 'center',
            headerStyle: { backgroundColor: '#2E5266' },
            headerTintColor: 'white',
            title: type === 'PATIENT' ? 'Diário' : 'Pacientes',
            tabBarIcon: ({ color, size, focused }) => (
              <NavigationBarItem
                color={color}
                size={size}
                focused={focused}
                children={<FontAwesome name="address-book-o" size={size} color={color} />}
              />
            )
          }}
        />
        <Tab.Screen name="Início"
          component={Home}
          options={{
            headerShown: false,
            tabBarIcon: ({ color, size, focused }) => (
              <NavigationBarItem
                color={color}
                size={size}
                focused={focused}
                children={<Entypo name="home" color={color} size={size} />}
              />
            )
          }}
        />
        <Tab.Screen name="Perfil"
          component={Profile}
          options={{
            headerShown: false,
            tabBarIcon: ({ color, size, focused }) => (
              <NavigationBarItem
                color={color}
                size={size}
                focused={focused}
                children={<FontAwesome5 name="user-alt" color={color} size={size} />}
              />
            )
          }}
        />
      </Tab.Navigator>
    );
  }

  return (
    <NavigationContainer>
      <Stack.Navigator screenOptions={{ headerShadowVisible: false }}>
        <Stack.Screen name="Login" component={Login} options={{ headerShown: false }} />
        <Stack.Screen name="Cadastrar" component={SignUp} options={{ headerTitleAlign: 'center' }} />
        <Stack.Screen name="TabScreens" component={TabScreens} options={{ headerShown: false }} />
        <Stack.Screen name="TalkToSpecialist" component={TalkToSpecialist} options={{ title: 'Falar com um especialista', headerTintColor: '#fff', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="SpecialistDetails" component={SpecialistDetails} options={{ title: 'Detalhes do profissional', headerTintColor: '#fff', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="SpecialistContact" component={SpecialistContact} options={{ title: 'Contato do especialista', headerShown: false }} />
        <Stack.Screen name="PatientDiaryCalendar" component={PatientDiaryCalendar} options={{ title: 'Diário', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#2E5266' }, headerTintColor: 'white', }} />
        <Stack.Screen name="PatientDiaryDaySpecialist" component={PatientDiaryDaySpecialist} options={{ title: 'Diário do Paciente', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="PatientDiaryDay" component={PatientDiaryDay} options={{ title: 'Diário do Paciente', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="InfoPage" component={InfoPage} options={{ title: 'Informações', headerTitleAlign: 'center' }} />
        <Stack.Screen name="Chat" component={Chat} options={{ headerTitleAlign: 'center' }} />
        <Stack.Screen name="ChatList" component={ChatList} options={{ headerTitleAlign: 'center', title: 'Falar com especialista' }} />
        <Stack.Screen name="Checklist" component={Checklist} options={{ title: 'Checklist', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="ChecklistInfo" component={ChecklistInfo} options={{ title: 'Checklist', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="Resultado" component={ChecklistResult} options={{ headerTitleAlign: 'center' }} />
        <Stack.Screen name="ClinicRegistration" component={ClinicRegistration} options={{ title: 'Inscrever Local de trabalho', headerTitleAlign: 'center' }} />
        <Stack.Screen name="PatientDiaryEntries" component={PatientDiaryEntries} options={{ title: 'Diários do paciente', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
        <Stack.Screen name="EditUserInfo" component={EditUserInfo} options={{ title: 'Editar Informações', headerTitleAlign: 'center' }} />
        <Stack.Screen name="EditDescription" component={EditDescription} options={{ title: 'Editar Descrição', headerTitleAlign: 'center', headerStyle: { backgroundColor: '#7197A6' } }} />
      </Stack.Navigator>
    </NavigationContainer >
  );
}