import { useRoute } from '@react-navigation/native';
import React, { useState, useCallback, useEffect } from 'react'
import { GiftedChat } from 'react-native-gifted-chat'
import { ChatParams } from '../@types/navigation';
import { useUser } from '../services/hooks/useUser';
import { useNavigation } from "@react-navigation/native";
import firebase from 'firebase/app';
import 'firebase/firestore';

interface IMessage {
  chat?: object,
  _id: number,
  text: string,
  createdAt: Date,
  user: {
    _id: number,
    _name: string,
    avatar: string,
  },
}

export function Chat() {
  const navigation = useNavigation();
  const [chat, setChat] = useState([]);
  const firestore = firebase.firestore();
  const [messages, setMessages] = useState<IMessage[]>([]);
  const router = useRoute();
  const { id, name } = router.params as ChatParams;
  const { user } = useUser();
  var docId = null;
  navigation.setOptions({ title: name })

  useEffect(() => {
    const getData = async () => {
      const chatsRef = firestore.collection('chats');
      var snapshot = null;
      var patientId = user.userType == 'PATIENT' ? user.id : id;
      var specialistId = user.userType == 'SPECIALIST' ? user.id : id;
      snapshot = await chatsRef.where("patient", "==", patientId).where("specialist", "==", specialistId).limit(1).get();
      if (snapshot.empty) {
        console.log('No matching documents.');
        await chatsRef.add({ patient: patientId, specialist: specialistId })
        snapshot = await chatsRef.where("patient", "==", patientId).where("specialist", "==", specialistId).limit(1).get();
      }
      snapshot.forEach(async doc => {
        docId = doc.id
        firestore.collection('chats').doc(doc.id).collection('messages').onSnapshot((querySnapshot) => {
          var msgs = [];
          querySnapshot.forEach((doc) => {
            msgs.push({
              _id: doc.id,
              text: doc.data().content,
              createdAt: new firebase.firestore.Timestamp(doc.data().timestamp.seconds, doc.data().timestamp.nanoseconds).toDate(),
              user: {
                _id: doc.data().sender,
                _name: doc.data().sender == user.id ? user.name : name,
                avatar: 'https://w7.pngwing.com/pngs/791/694/png-transparent-female-silhouette-user-avatar-animals-head-woman.png',
              }
            });
          });
          msgs.sort((a, b) => b.createdAt - a.createdAt)
          setChat(msgs)
        });
      });
    }
    getData();
    setMessages(chat)
  }, []);

  const onSend = useCallback((message) => {
    firestore.collection('chats').doc(docId).collection('messages').add({
      content: message.text,
      sender: user.id,
      timestamp: firebase.firestore.Timestamp.fromDate(new Date()),
    })
  }, [])


  return (
    <GiftedChat
      messages={chat}
      onSend={messages => onSend(messages[0])}
      user={{
        _id: user.id,
        name: user.name,
        avatar: 'https://w7.pngwing.com/pngs/791/694/png-transparent-female-silhouette-user-avatar-animals-head-woman.png',
      }}
    />
  )
}