import { CheckBox } from '@rneui/themed';
import React, { useEffect, useState } from 'react';
import { View, StyleSheet, ScrollView } from 'react-native';
import { colorPalette } from "../components/Theme";
import { SafeAreaView } from 'react-native-safe-area-context';
import { AppButton } from '../components/AppButton';
import { api } from '../services/api';
import { useNavigation } from '@react-navigation/native';
import { AxiosError } from 'axios';
import { callToast } from '../utils/toast';

type ChecklistItem = {
  checklistId: number;
  symptom: Symptom;
  answer: boolean;
}

type Symptom = {
  symptomId: number;
  description: string;
  weight: number;
}

export function Checklist() {
  const [checklistItems, setChecklistItems] = useState<ChecklistItem[]>([]);
  const [updating, setUpdating] = useState(false);
  const navigation = useNavigation();

  useEffect(() => {
    api.get('/checklist/user').then((response) => {
      setChecklistItems(response.data);
    })
  }, [])

  function handleUpdateState(listItem: ChecklistItem) {
    setUpdating(true);
    api.put('/checklist', { checklistId: listItem.checklistId, answer: !listItem.answer }).then(
      (response) => {
        if (response.status === 200) {
          const newState = checklistItems.map((item) => {
            if (item.checklistId === listItem.checklistId) {
              return { ...item, answer: !item.answer }
            }
            return item;
          })
          setChecklistItems(newState);
        }
      }).catch((error: AxiosError) => {
        callToast(error.response.data as string)
      });
    setUpdating(false);
  }


  return (
    <SafeAreaView style={styles.container}>
      <ScrollView>
        {checklistItems.map((item) => {
          return (
            <CheckBox
              key={item.checklistId}
              title={item.symptom.description}
              checked={item.answer}
              onPress={() => handleUpdateState(item)}
              containerStyle={{ alignSelf: "center", height: "8%", flex: 1, flexWrap: 'wrap' }}
              disabled={updating}
              textStyle={{   }}
              
            />
          )
        })}
        <View style={{ width: "85%", alignSelf: "center", marginRight: "7%", paddingBottom: "2%" }}>
          <AppButton buttonLabel='Finalizar checklist' onPress={() => navigation.navigate('Resultado')} />
        </View>
      </ScrollView>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  container: {
    height: "100%",
    width: "100%",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: colorPalette.neutral[0]
  }
});