import { Icon, Text } from "@rneui/themed";
import React from "react";
import { SafeAreaView, ScrollView, StyleSheet, TouchableOpacity, View } from "react-native";
import { AppButton } from "../components/AppButton";
import { colorPalette } from "../components/Theme";
import { MaterialCommunityIcons } from '@expo/vector-icons';
import { useNavigation } from "@react-navigation/native";


const diagnostic_types = [
  {
    name: "Autismo leve",
    color: colorPalette.primary[300],
  },
  {
    name: "Autismo moderado",
    color: "#B09048",
  },
  {
    name: "Autismo severo",
    color: "#D8685D",
  },
];

export function ChecklistInfo() {
  const navigation = useNavigation();
  return (
    <SafeAreaView style={styles.screen}>
      <ScrollView >
        <View style={styles.header__container}>
          <View style={styles.header__icon__container}>
            <Icon
              type="font-awesome-5"
              name="clipboard-list"
              size={38}
              color={colorPalette.neutral[0]}
            />
          </View>
          <Text style={styles.header__text}>
            Complete o checklist para identificar comportamentos do transtorno
            do espectro autista em sua criança.
          </Text>
        </View>
        <View style={styles.body}>
          <View style={styles.diagnostic_types__container}>
            <Text style={styles.diagnostic_types__title}>
              Tipos de autismo
            </Text>
            {diagnostic_types.map((type, index) => {
              const type_style = StyleSheet.create({
                text: { color: type.color },
              });
              return (
                <View style={styles.diagnostic_types__item__container} key={index}>
                  <MaterialCommunityIcons name="puzzle" size={24} style={{ color: type.color, rotation: -10 }} />
                  <View style={styles.diagnostic_types__item}>
                    <Text
                      style={StyleSheet.flatten([
                        styles.diagnostic_types__text,
                        type_style.text,
                      ])}
                    >
                      {type.name}
                    </Text>
                  </View>
                </View>
              );
            })}
          </View>
          <View
            style={{
              marginTop: "4%",
              width: "100%",
              display: "flex",
              paddingVertical: "4%",
              backgroundColor: colorPalette.neutral[100],
              borderRadius: 16,
              justifyContent: "center",
              alignItems: "center",
            }}
          >
            <Text>Já possui um diagnóstico?</Text>
            <TouchableOpacity onPress={() => navigation.navigate('TalkToSpecialist')}>
              <Text style={styles.tertiary_button}>
                Falar com um especialista
              </Text>
            </TouchableOpacity>
          </View>
          <AppButton buttonLabel="Iniciar checklist" onPress={() => navigation.navigate('Checklist')} />
        </View>
      </ScrollView>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  screen: {
    height: "100%",
    display: "flex",
  },
  header__container: {
    backgroundColor: '#7197A6',
    gradient: ['#ADD3DE', '#2E5266'],
    alignItems: "center",
    paddingVertical: "8%",
    paddingHorizontal: "7%",
  },
  header__icon: {
    fontSize: 64,
  },
  header__icon__container: {
    borderRadius: 10,
    backgroundColor: colorPalette.primary[100],
    height: 90,
    width: "30%",
    display: "flex",
    justifyContent: "center",
    marginBottom: "4%",
  },
  header__text: {
    color: colorPalette.neutral[0],
    fontWeight: "400",
    fontSize: 16,
    lineHeight: 28,
    letterSpacing: 0.75,
    textAlign: "center",
  },
  body: {
    height: "100%",
    padding: "7%",
    alignItems: "center",
    backgroundColor: colorPalette.neutral[0],
  },
  diagnostic_types__container: {
    backgroundColor: colorPalette.neutral[100],
    borderRadius: 16,
    padding: 16,
    width: "100%",
  },
  diagnostic_types__title: {
    fontWeight: "400",
    fontSize: 12.5,
    lineHeight: 22.5,
    letterSpacing: 0.75,
    color: colorPalette.neutral[900],
  },
  diagnostic_types__item__container: {
    backgroundColor: colorPalette.neutral[0],
    width: "100%",
    paddingHorizontal: "8%",
    paddingVertical: "4%",
    borderRadius: 16,
    display: "flex",
    flexDirection: "row",
    marginVertical: "2%",
  },
  diagnostic_types__text: {
    fontWeight: "700",
    fontSize: 16,
    lineHeight: 25,
    letterSpacing: 0.75,
    textTransform: "uppercase",
  },
  diagnostic_types__item: {
    width: "100%",
    display: "flex",
    flexDirection: "row",
    justifyContent: "center",
    alignContent: "center",
  },
  tertiary_button: {
    color: colorPalette.primary[700],
    fontWeight: "bold",
    fontSize: 16,
  },
});

