import React, { useEffect, useState } from 'react';
import { View, Text, StyleSheet, ScrollView, Platform } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import { AppButton } from '../components/AppButton';
import { MaterialCommunityIcons } from '@expo/vector-icons';
import { LinearGradient } from 'expo-linear-gradient';
import { api } from '../services/api';

export function ChecklistResult() {
  const navigation = useNavigation();

  const [isLoading, setLoading] = useState(true);
  const [statusMessage, setStatusMessage] = useState('Carregando...');
  const [data, setData] = useState({
    title: '', level: 0, gradient: ['#FFF', '#000'], color: 'white', textColor: '#445d8fa2', bgColor: 'black', text: ''
  });

  useEffect(() => {
    api.get('/checklist/result').then((response) => {
      let data;
      if (response.data <= 25) {
        navigation.setOptions({ headerStyle: { backgroundColor: '#3690c0' } });
        data = {
          gradient: ['#3690c0', '#3690c08d'],
          bgColor: 'rgba(126, 144, 181, 0)',
          color: '#445d8fa2',
          textColor: '#445d8fa2',
          title: 'muita baixa de autismo',
          text: 'O resultado não demonstrou que sua criança apresenta características de autismo. Mesmo assim, recomendamos consultar com um especialista.',
        }
      }
      else if (response.data <= 50) {
        navigation.setOptions({ headerStyle: { backgroundColor: '#5FBABE' } });
        data = {
          gradient: ['#5FBABE', '#61CEB9'],
          bgColor: 'rgba(67, 144, 159, 0)',
          color: '#438F9F',
          textColor: '#438F9F',
          title: 'baixo de autismo',
          text: 'Menor necessidade de apoio no dia a dia. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit amet, consectetur adipiscing elit.',
        }
      }
      else if (response.data <= 75) {
        navigation.setOptions({ headerStyle: { backgroundColor: '#fcac34dd' } });
        data = {
          gradient: ['#fcac34dd', '#ffcc80c7'],
          bgColor: 'rgba(176, 145, 72, 0)',
          color: '#B09048',
          textColor: '#B09048',
          title: 'moderada de autismo',
          text: 'Popularmente conhecido como autismo moderado, nesse nível a pessoa precisa de um pouco mais de apoio em sua rotina. Lorem ipsum dolor sit amet.',
        }
      } else {
        navigation.setOptions({ headerStyle: { backgroundColor: '#ff2424d1' } });
        data = {
          gradient: ['#ff2424d1', '#ff747478'],
          bgColor: 'rgba(172, 99, 83, 0)',
          color: '#ff3939',
          textColor: '#E06D62',
          title: 'elevada de autismo',
          text: 'Conhecido como autismo severo, a pessoa precisa de mais apoio para as atividades da vida diária. Lorem ipsum dolor sit amet, consectetur adipiscing elit. ',
        }
      }
      setData(data);
      setLoading(false);
    }).catch(() => {
      setStatusMessage('Ocorreu um erro ao carregar este resultado.');
    });
  }, []);


  return isLoading
    ? (
      <View style={{ ...styles.container, justifyContent: 'center' }}>
        <Text style={{ fontSize: 20, textAlign: 'center', padding: 30 }}>{statusMessage}</Text>
      </View>
    )
    : (
      <ScrollView style={{ backgroundColor: 'white' }}>
        <View style={styles.container} >
          <LinearGradient
            colors={data.gradient}
            style={styles.header}
          >
            <View style={{ ...styles.header, backgroundColor: data.bgColor }}>
              <View style={styles.iconsCcontainer}>
                <MaterialCommunityIcons name="puzzle" size={24} style={{ ...styles.firstIcon, color: data.color }} />
                <MaterialCommunityIcons name="puzzle" size={24} style={{ ...styles.secondIcon, color: data.color }} />
              </View>
              <View style={styles.resultCcontainer}>
                <Text style={{ ...styles.resultText }}>Suspeita</Text>
                <Text style={Platform.OS === "ios" ? { ...styles.resultTitleIOS, color: data.textColor } : { ...styles.resultTitle, color: data.textColor }}>{data.title}</Text>
              </View>
            </View>
          </LinearGradient>
          <Text style={styles.descriptionText}>{data.text}</Text>
          <View style={styles.alertBox}>
            <MaterialCommunityIcons name="information" style={styles.infoIcon} size={24} />
            <Text style={styles.alertText}>Este resultado não é um diagnóstico verdadeiro, apenas uma previsão. Contate um especialista para obter um diagnóstico real.</Text>
          </View>
          <AppButton buttonLabel="Falar com um especialista" onPress={() => navigation.navigate('TalkToSpecialist')} style={{ width: "85%" }} />
        </View>
      </ScrollView>
    );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: "center",
    justifyContent: 'center',
  },
  header: {
    justifyContent: 'center',
    alignItems: "center",
    height: 270,
    width: '100%',
    maxHeight: 375,
    paddingVertical: 30,
  },
  iconsCcontainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: "center",
    marginBottom: "5%"
  },
  firstIcon: {
    fontSize: 80,
    marginLeft: -65,
    rotation: -10,
    transform: [{ rotate: '-10deg' }]
  },
  secondIcon: {
    fontSize: 80,
    marginLeft: 65,
    marginTop: -45,
    rotation: 20,
    transform: [{ rotate: '20deg' }]
  },
  resultCcontainer: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: "center",
    backgroundColor: 'white',
    borderRadius: 20,
    width: '70%',
    marginTop: -30,
    height: 70,
  },
  resultText: {
    fontSize: 16,
    textTransform: 'uppercase',
  },
  resultTitle: {
    fontSize: 18,
    textTransform: 'uppercase',
    fontWeight: 'bold',
  },
  resultTitleIOS: {
    fontSize: 16,
    textTransform: 'uppercase',
    fontWeight: 'bold',
  },
  resultSpan: {
    fontSize: 16,
    marginTop: 10,
    color: 'white',
  },
  descriptionText: {
    width: '85%',
    paddingVertical: 25,
    textAlign: 'center',
    fontSize: 18,
  },
  alertText: {
    padding: 15,
    fontSize: 16,
    marginLeft: 40,
    marginTop: -40,
  },
  alertBox: {
    width: '85%',
    backgroundColor: 'rgba(109, 79, 211, 0.05)',
    borderRadius: 10,
    marginBottom: 10,
  },
  infoIcon: {
    paddingTop: 15,
    paddingLeft: 15,
    color: '#2E5266',
  }
});