import React, { useEffect, useState } from "react";
import { View, StyleSheet, Text, TextInput, SafeAreaView, ScrollView } from "react-native";
import { AppButton } from "../components/AppButton";
import { colorPalette } from "../components/Theme";
import { Entypo } from '@expo/vector-icons';
import { api } from "../services/api";
import { AxiosError } from "axios";
import { callToast } from "../utils/toast";
import { useNavigation } from "@react-navigation/native";

export function EditDescription() {
  const [description, setDescription] = useState("");
  const navigation = useNavigation();

  useEffect(() => {
    api.get("/descriptions/user").then((response) => {
      setDescription(response.data.description)
    })
  }, [])

  function editUserDescription() {
    api.post("/descriptions", { description }).then((response) => {
      callToast("Descrição alterada com sucesso.");
      navigation.goBack();
    }).catch((error: AxiosError) => callToast(error.response.data as string))
  }

  return (
    <SafeAreaView style={styles.container}>
      <ScrollView>
        <View style={styles.topContainer}>
          <View style={styles.iconContainer}>
            <Entypo name="text" size={36} color={colorPalette.neutral[0]} />
          </View>
          <Text style={styles.topContainerText}>
            Adicione uma descrição ao seu perfil. Ficará visível para os possíveis pacientes
            na lista de especialistas.
          </Text>
        </View>
        <View style={styles.content}>
          <TextInput
            style={styles.input}
            underlineColorAndroid="transparent"
            placeholderTextColor={"#8b9cb5"}
            maxLength={90}
            multiline={true}
            value={description}
            onChangeText={(value) => setDescription(value)}
          />
          <Text style={{ alignSelf: "flex-start" }}>Caracteres restantes: {description ? description.length : 0}/90</Text>
          <AppButton
            buttonLabel="Iniciar checklist"
            onPress={() => editUserDescription()}
          />
        </View>
      </ScrollView>
    </SafeAreaView >
  )
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: "white"
  },
  topContainer: {
    backgroundColor: '#7197A6',
    gradient: ['#ADD3DE', '#2E5266'],
    alignItems: "center",
    paddingVertical: "5%",
    paddingHorizontal: "7%",
  },
  iconContainer: {
    borderRadius: 10,
    backgroundColor: colorPalette.primary[100],
    height: 90,
    width: "30%",
    justifyContent: "center",
    alignItems: "center",
    marginBottom: "4%",
  },
  topContainerText: {
    color: colorPalette.neutral[0],
    fontWeight: "400",
    fontSize: 16,
    lineHeight: 28,
    letterSpacing: 0.75,
    textAlign: "center",
  },
  content: {
    justifyContent: "center",
    alignItems: "center",
    width: "100%",
    paddingLeft: "8%",
    paddingRight: "8%",
    marginTop: "4%",
  },
  input: {
    backgroundColor: colorPalette.neutral[100],
    padding: 20,
    margin: 10,
    borderRadius: 16,
    width: '100%',
    height: 150,
    fontSize: 16,
    textAlignVertical: "top"
  }
});

