import React from "react";
import {
  View,
  Text,
  StyleSheet,
  ScrollView,
} from "react-native";
import { Image } from "@rneui/themed";
import { colorPalette } from "../components/Theme";
import HomeCard from "../components/HomeCard";
import { useNavigation } from "@react-navigation/native";
import { useUser } from "../services/hooks/useUser";

export function Home() {
  const navigation = useNavigation();
  const { user } = useUser();

  const navigateChecklist = () => {
    navigation.navigate("ChecklistInfo");
  };

  const navigateContatoEspecialista = () => {
    navigation.navigate("ChatList");
  };

  const navigateDiarioPaciente = () => {
    navigation.navigate("PatientDiaryCalendar");
  };
  const navigateInfoPage = () => {
    navigation.navigate("InfoPage");
  };

  let homeCards =
    user.userType === "PATIENT" ? (
      <>
        <HomeCard
          title="Checklist"
          description="Realizar o checklist para obter um diagnóstico precoce"
          imageUri="https://hilab.com.br/wp-content/uploads/2021/11/Anamnese-farmaceutica-Hilab.jpg"
          icon={{ type: "font-awesome-5", name: "clipboard-list" }}
          onPress={navigateChecklist}
        />
        <HomeCard
          title="Contatar Especialista"
          description="Entrar em contato diretamente com um especialista"
          imageUri="https://www.safercorretora.com.br/wp-content/uploads/bb-plugin/cache/plano-de-saude-para-medico-landscape.jpg"
          icon={{ type: "font-awesome-5", name: "plus-square" }}
          onPress={navigateContatoEspecialista}
        />
        <HomeCard
          title="Diário do paciente"
          description="Escreva anotações no seu diário. Conte como se sente!"
          imageUri="https://segurancadopaciente.com.br/wp-content/uploads/2018/06/checklist-735x460.jpg"
          icon={{ type: "font-awesome-5", name: "address-book" }}
          onPress={navigateDiarioPaciente}
        />
        <HomeCard
          title="Sobre o autismo"
          description="Aqui você pode ver os materiais sobre o autismo"
          imageUri="https://www.sarahdooleycenter.org/wp-content/uploads/2021/10/bigstock-Father-And-Autistic-Son-Hands-412455478-1024x683.jpg"
          icon={{ type: "font-awesome-5", name: "puzzle-piece" }}
          onPress={navigateInfoPage}
        />
      </>
    ) : (
      <>
        <HomeCard
          title="Meus pacientes"
          description="Acesso a todos os seus pacientes no aplicativo"
          imageUri="https://media.istockphoto.com/photos/cropped-view-of-african-american-man-writing-something-on-paper-in-picture-id803114058?b=1&k=20&m=803114058&s=170667a&w=0&h=i1fgkEdyyesFKPFY8du5OzY1-W9U_3nuI-A4OD99pdw="
          icon={{ type: "font-awesome-5", name: "address-book" }}
          onPress={navigateChecklist}
        />
        <HomeCard
          title="Solicitações"
          description="Solicitações de pacientes para entrar em contato com você"
          imageUri="https://www.institutophd.com.br/wp-content/uploads/2011/12/O-que-%C3%A9-Pesquisa-Focus-Group-e-quais-suas-principais-aplica%C3%A7%C3%B5es-1024x673.png"
          icon={{ type: "font-awesome-5", name: "plus-square" }}
          onPress={navigateContatoEspecialista}
        />
        <HomeCard
          title="Sobre o autismo"
          description="Aqui você pode ver os materiais sobre o autismo"
          imageUri="https://www.sarahdooleycenter.org/wp-content/uploads/2021/10/bigstock-Father-And-Autistic-Son-Hands-412455478-1024x683.jpg"
          icon={{ type: "font-awesome-5", name: "puzzle-piece" }}
          onPress={navigateInfoPage}
        />
      </>
    );

  return (
    <>
      <ScrollView>
        <View style={styles.container}>
          <View
            style={{
              display: "flex",
              flexDirection: "row",
              justifyContent: "center",
              alignItems: "center",
              marginTop: 32,
            }}
          >
            <Image
              source={require("../assets/images/logo.png")}
              style={{ height: 50, width: 50 }}
            />
            <Text
              style={{
                fontWeight: "400",
                fontSize: 20,
                lineHeight: 28,
                color: colorPalette.neutral[900],
                paddingLeft: 4,
              }}
            >
              Meu Mundo Azul
            </Text>
          </View>
          {homeCards}
        </View>
      </ScrollView>
    </>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    display: "flex",
    justifyContent: "center",
    alignItems: "center",
    backgroundColor: "white",
    paddingBottom: 24,
  },
});
