import React, { useState } from 'react';
import { View, Text, StyleSheet, TouchableOpacity, KeyboardAvoidingView, Platform } from 'react-native';
import { useNavigation } from '@react-navigation/native';
import { AppButton } from '../components/AppButton';
import { Logo } from '../components/Logo';
import { InputDefault } from '../components/InputDefault';
import { useUser } from '../services/hooks/useUser';
import { Divider } from '@rneui/themed';

export function Login() {
  const navigation = useNavigation();
  const { login } = useUser();
  const [email, setEmail] = useState('');
  const [password, setPassword] = useState('');

  const recuperar = () => { alert('Um e-mail foi enviado para ' + email); }
  const cadastrar = () => { navigation.navigate('Cadastrar'); }
  const entrar = async () => {
    const emailFormatted = email.toLowerCase();
    const responseCode = await login({ email: emailFormatted, password })
    if (responseCode === 200) {
      navigation.navigate('TabScreens', { screen: 'Home', initial: false });
    }
  }
  return (
    <KeyboardAvoidingView
      behavior={Platform.OS === "ios" ? "padding" : "height"}
      keyboardVerticalOffset={50}
      style={styles.container}>
      <Logo margin={true} />
      <InputDefault
        placeholder="E-mail"
        keyboardType="email-address"
        value={email}
        onChangeText={(text) => setEmail(text)}
      />
      <InputDefault
        placeholder="Senha"
        value={password}
        onChangeText={(text) => setPassword(text)}
        secureTextEntry={true}
      />
      <AppButton buttonLabel="Entrar" onPress={entrar} style={{ width: "85%" }} />
      <View style={styles.forgotArea}>
        <Text style={{ fontSize: 16 }}>Esqueceu a senha?</Text>
        <TouchableOpacity onPress={() => recuperar()}>
          <Text style={styles.forgot}> Recuperar</Text>
        </TouchableOpacity>
      </View>
      <View style={styles.dividerArea}>
        <Divider />
        <Text>ou</Text>
        <Divider />
      </View>
      <AppButton buttonLabel="Cadastrar" onPress={cadastrar} style={{ width: "85%" }} />
    </KeyboardAvoidingView>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: "#FFF",
    justifyContent: "center",
    alignItems: "center",
  },
  forgotArea: {
    flexDirection: "row",
    fontSize: 16,
    marginBottom: 10,
  },
  forgot: {
    color: "#618793",
    fontWeight: "bold",
    fontSize: 16,
  },
  dividerArea: {
    display: "flex",
    flexDirection: "row",
    width: "85%",
  },
});
