import React, { useState } from "react";
import { ScrollView, StyleSheet, View, Text } from "react-native";
import { AppButton } from "../components/AppButton";
import { colorPalette } from "../components/Theme";
import { useNavigation } from "@react-navigation/native";
import CalendarPicker from 'react-native-calendar-picker';
import { LinearGradient } from "expo-linear-gradient";
import moment from "moment";
import { Icon } from "@rneui/base";

export function PatientDiaryCalendar() {
  const [currentDate, setCurrentDate] = useState(new Date());
  const momentDate = moment(currentDate).utc().format('DD/MM/YYYY');
  const navigation = useNavigation();
  return (
    <ScrollView style={{ backgroundColor: 'white' }}>
      <View style={styles.container}>
        <LinearGradient
          colors={['#2E5266', '#2E5266', '#2E5266']}
          style={styles.header}
        >
          <View style={styles.headerIconContainer}>
            <Icon
              type="font-awesome-5"
              name="address-book"
              size={36}
              color={colorPalette.neutral[0]}
            />
          </View>
          <View style={styles.textContainer}>
            <Text style={styles.text}>
              Guarde anotações sobre o seu dia no seu diário do paciente.
            </Text>
          </View>
        </LinearGradient>
        <View style={styles.content}>
          <View style={styles.calendar}>
            <CalendarPicker
              weekdays={['Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sab']}
              months={['Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Dezembro']}
              previousTitle="Anterior"
              nextTitle="Próximo"
              width={330}
              defaultTodayBackgroundColor='white'
              onDateChange=
              {
                (currentDate) => setCurrentDate(currentDate)
              }
            />
          </View>
          <AppButton buttonLabel="Acessar diário" onPress={() => navigation.navigate('PatientDiaryDay', { date: momentDate })} />
        </View>
      </View>
    </ScrollView>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: "center",
    justifyContent: 'center',
  },
  header: {
    flex: 1,
    justifyContent: 'center',
    alignItems: "center",
    width: '100%',
    maxHeight: 375,
  },
  content: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: "center",
    justifyContent: 'center',
    height: '100%',
    width: '85%',
    paddingBottom: 60,
  },
  calendar: {
    justifyContent: 'center',
    alignItems: "center",
    backgroundColor: 'white',
    height: 330,
    width: '100%',
    marginTop: -40,
    marginBottom: 30,
    borderRadius: 14,
    shadowColor: 'black',
    shadowOffset: { width: 0, height: 0 },
    shadowOpacity: 0.2,
    shadowRadius: 5,
    elevation: 5,
  },
  textContainer: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 20,
    width: '80%',
    marginBottom: 55,
  },
  text: {
    textAlign: 'center',
    fontSize: 16,
    letterSpacing: 0.75,
    color: 'white',
  },
  headerIconContainer: {
    borderRadius: 10,
    backgroundColor: colorPalette.primary[100],
    height: 80,
    width: '23%',
    display: "flex",
    justifyContent: "center",
    marginTop: 30,
    marginBottom: "7%",
  },
});

