import {
  Text,
  View,
  StyleSheet,
  Image,
  KeyboardAvoidingView,
  Platform,
} from "react-native";
import { useRoute } from '@react-navigation/native';
import { colorPalette } from "../components/Theme";
import { DiaryDayParams } from "../@types/navigation";

export function PatientDiaryDaySpecialist() {
  const router = useRoute();
  const { date, text } = router.params as DiaryDayParams;

  return (
    <KeyboardAvoidingView
      behavior={Platform.OS === "ios" ? "padding" : "height"}
      keyboardVerticalOffset={120}
      style={styles.container}
    >
      <View style={styles.calendar}>
        <Image
          source={require("../assets/images/calendar_icon.png")}
          style={styles.imageStyle}
        />
        <Text style={styles.dateStyle}>{date}</Text>
      </View>
      <View style={styles.input}>
        <Text style={{ fontSize: 18, letterSpacing: 0.3 }}>{text}</Text>
      </View>
    </KeyboardAvoidingView>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    height: "100%",
    width: "100%",
    display: "flex",
    alignItems: "center",
    justifyContent: "flex-start",
    backgroundColor: "white",
  },
  input: {
    backgroundColor: "white",
    margin: 10,
    width: "83%",
    height: "65%",
    textAlignVertical: "top",
  },
  dateStyle: {
    textAlign: "center",
    fontSize: 20,
    color: 'black',
  },
  imageStyle: {
    padding: 10,
    margin: 20,
    height: 20,
    width: 20,
    resizeMode: "stretch",
  },
  calendar: {
    flexDirection: "row",
    backgroundColor: colorPalette.neutral[100],
    justifyContent: "flex-start",
    marginTop: 25,
    marginBottom: 10,
    borderRadius: 7,
    width: "85%",
    height: 64,
    fontSize: 20,
    alignItems: "center",
  },
});
