import React, { useEffect, useState } from "react";
import { Text, StyleSheet, ScrollView, TouchableOpacity, View } from "react-native";
import { api } from "../services/api";
import { SafeAreaView } from "react-native-safe-area-context";
import { colorPalette } from "../components/Theme";
import { useNavigation, useRoute } from "@react-navigation/native";
import { PatientDiaryEntriesParams } from "../@types/navigation";
import moment from "moment";
import { Divider } from "@rneui/base";

type DiaryItem = {
  diaryId: number;
  date: string;
  text: string;
};

export function PatientDiaryEntries() {
  const [diaryItens, setDiaryItens] = useState<DiaryItem[]>([]);
  const navigation = useNavigation();
  const router = useRoute();
  const { id } = router.params as PatientDiaryEntriesParams;

  useEffect(() => {
    api.get(`/diaries/user/${id}`).then((response) => {
      setDiaryItens(response.data);
    });
  }, []);

  return (
    <SafeAreaView style={styles.container}>
      <ScrollView style={{ width: "90%" }}>
        {diaryItens.map((item, index) => {
          return (
            <View key={item.diaryId}>
              <TouchableOpacity
                style={styles.dairyContent}
                onPress={() =>
                  navigation.navigate("PatientDiaryDaySpecialist", {
                    date: item.date,
                    text: item.text,
                  })
                }
              >
                <Text style={styles.textDay}>Dia: {item.date}</Text>
                <Text style={styles.text}>
                  {item.text.length > 35
                    ? item.text.substring(0, 35) + "..."
                    : item.text}
                </Text>
              </TouchableOpacity>
              <Divider
                width={2}
                style={{
                  ...styles.divider,
                  display: diaryItens.length - 1 === index ? "none" : "flex",
                }}
              />
            </View>
          );
        })}
      </ScrollView>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  container: {
    height: "100%",
    width: "100%",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: colorPalette.neutral[0],
  },
  dairyContent: {
    borderRadius: 15,
    alignItems: "flex-start",
    justifyContent: "center",
    padding: 20,
    backgroundColor: colorPalette.primary[50],
  },
  text: {
    textAlign: "left",
    fontSize: 16,
    letterSpacing: 0.75,
    color: "black",
  },
  textDay: {
    textAlign: "left",
    fontSize: 17,
    letterSpacing: 0.75,
    color: "black",
    marginBottom: 10,
  },
  divider: {
    margin: 20,
    width: 40,
    alignSelf: "center",
    borderRadius: 10,
  },
});
