import { View, StyleSheet } from 'react-native';
import { ProfileOption } from '../components/ProfileOption';
import { useNavigation } from '@react-navigation/native';
import { ProfileLogo } from '../components/ProfileLogo';
import { useUser } from '../services/hooks/useUser';

export function Profile() {
  const navigation = useNavigation();
  const { user } = useUser();
  let userType = user.userType;
  var name = user.name;
  var initials: string;

  if (name != null) {
    const splits = name.split(" ");
    const tam = splits.length;
    const firstName = splits[0];
    const lastname = splits[tam - 1];
    const firstLetter = firstName.charAt(0);
    const secondLetter = lastname.charAt(0);
    initials = firstLetter + secondLetter;
  }

  const editInfo = () => { navigation.navigate('EditUserInfo'); }
  const doChecklist = () => { navigation.navigate('ChecklistInfo'); }
  const exit = () => { navigation.navigate('Login'); }
  const addWorkstation = () => { navigation.navigate('ClinicRegistration'); }
  const editDescription = () => { navigation.navigate('EditDescription') }

  return (
    <View style={styles.container}>
      <ProfileLogo name={name} init={initials} />
      <View style={styles.profile} >
        <ProfileOption iconName={"pencil"} text={"Editar Informações"} onPress={editInfo} />
        {
          (userType === "PATIENT") ?
            <ProfileOption
              iconName={"clipboard-list"}
              text={"Fazer Checklist"}
              onPress={doChecklist}
            />
            :
            <>
              <ProfileOption
                iconName={"plus"}
                text={"Adicionar local de trabalho"}
                onPress={addWorkstation}
              />
              <ProfileOption
                iconName={"plus"}
                text={"Adicionar descrição"}
                onPress={editDescription}
              />
            </>
        }
        <ProfileOption iconName={"exit-to-app"} text={"Sair"} onPress={exit} />
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: "center",
    alignItems: "center",
    backgroundColor: 'white',
  },
  profile: {
    flex: 0.5,

  },
  divider: {
    height: 5,
    backgroundColor: '#ADD3DE',
    width: '37%',
    margin: 9,
    borderRadius: 10
  }
});