import React, { useEffect, useState } from 'react';
import { View, Text, StyleSheet, ScrollView, FlatList } from 'react-native';
import { colorPalette } from '../components/Theme';
import { Feather } from '@expo/vector-icons';
import { SpecialistCard } from '../components/SpecialistCard';
import { api } from '../services/api';
import { useNavigation } from '@react-navigation/native';
import { AxiosError } from 'axios';
import { callToast } from '../utils/toast';

type SpecialistItem = {
  occupationArea: string,
  specialistDescription: string,
  specialistId: string,
  specialistName: string
}

export function TalkToSpecialist() {
  const navigation = useNavigation();
  const [specialists, setSpecialists] = useState<SpecialistItem[]>([]);


  useEffect(() => {
    api.get('/clinics/user-details').then((response) => {
      setSpecialists(response.data);
    }).catch((error: AxiosError) => callToast(error.code as string));
  }, [])

  return (
    <><View style={styles.header__container}>
      <View style={styles.header__icon__container}>
        <Feather name='plus-square' size={64} color={colorPalette.neutral[0]} />
      </View>
      <Text style={styles.header__text}>Veja os profissionais disponíveis para prestar um atendimento especializado.</Text>
    </View>
      <ScrollView>
        {specialists.map(item => {
          return (
            <React.Fragment key={item.specialistId}>
              <SpecialistCard name={item.specialistName}
                description={item.specialistDescription}
                occupationArea={item.occupationArea}
                onPress={() => navigation.navigate('SpecialistDetails', {
                  specialistId: item.specialistId,
                  specialistName: item.specialistName,
                  specialistDescription: item.specialistDescription,
                })} />
            </React.Fragment>
          )
        })}
      </ScrollView></>
  );
}

const styles = StyleSheet.create({
  header__container: {
    backgroundColor: '#7197A6',
    gradient: ['#ADD3DE', '#2E5266'],
    alignItems: "center",
    paddingVertical: "8%",
    paddingHorizontal: "7%",
  },
  item: {

  },
  header__icon: {
    fontSize: 64,
  },
  header__icon__container: {
    borderRadius: 10,
    backgroundColor: colorPalette.primary[100],
    height: 90,
    width: "30%",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
    marginBottom: "4%",
  },
  header__text: {
    color: colorPalette.neutral[0],
    fontWeight: "400",
    fontSize: 16,
    lineHeight: 28,
    letterSpacing: 0.75,
    textAlign: "center",

  },
});