const phoneRegex = /^\([1-9]{2}\) [8-9]{1}[0-9]{4}\-[0-9]{4}$/g;
const nameRegex = /^[A-zÀ-ÿ]+ [A-zÀ-ÿ]/g;
const birthdayRegex =
  /(0[1-9]|[12][0-9]|3[01])\/(0[1-9]|1[012])\/(19|20)\d{2}/g;
const cpfRegex = /([0-9]{3}.){3}[0-9]{2}/g;
const crmRegex = /[0-9]{6}/g;
const emailRegex =
  /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;

export function isNameValid(name: string): string {
  if (name === "" || name === undefined) {
    return "É necessário informar o nome";
  } else if (!name.match(nameRegex)) {
    return "É necessário inserir o nome completo";
  }
  return "valid";
}

export function isPhoneValid(phone: string): string {
  if (phone === "" || phone === undefined) {
    return "É necessário informar um celular";
  } else if (!phone.match(phoneRegex)) {
    return "Número inválido";
  }
  return "valid";
}

export function isBirthdayValid(birthday: string): string {
  if (birthday === "" || birthday === undefined) {
    return "É necessário informar a data de nascimento";
  } else if (!birthday.match(birthdayRegex)) {
    return "Data de nascimento inválida";
  }
  return "valid";
}

export function isCpfValid(cpf: string): string {
  if (cpf === "" || cpf === undefined) {
    return "É necessário informar o cpf";
  } else if (!cpf.match(cpfRegex)) {
    return "CPF inválido";
  }
  return "valid";
}

export function isCrmValid(crm: string): string {
  if (crm === "" || crm === undefined) {
    return "É necessário informar o CRM ou CRP";
  } else if (!crm.match(crmRegex)) {
    return "CRM ou CRP inválido";
  }
  return "valid";
}

export function isDiaryValid(diary: string): string {
  if (diary === "" || diary === undefined) {
    return "É necessário preencher o diário";
  }
  return "valid";
}

export function isEmailValid(email: string): string {
  if (email === "" || email === undefined) {
    return "É necessário informar o e-mail";
  } else if (!email.match(emailRegex)) {
    return "E-mail inválido";
  }
  return "valid";
}

export function isPasswordValid(password: string): string {
  if (password === "" || password === undefined) {
    return "É necessário criar uma senha";
  }
  return "valid";
}

export function isPasswordsEqualsValid(
  password: string,
  passwordConfirmation: string
): string {
  if (password !== passwordConfirmation) {
    return "As senhas devem ser iguais";
  }
  return "valid";
}

export function isInputNotEmpty(input: string): string {
  if (input === "" || input === undefined) {
    return "É necessário preencher este campo";
  }
  return "valid";
}
